#[non_exhaustive]pub struct Epoch {
pub epoch: Option<u64>,
pub committee: Option<ValidatorCommittee>,
pub bcs_system_state: Option<BcsData>,
pub first_checkpoint: Option<u64>,
pub last_checkpoint: Option<u64>,
pub start: Option<Timestamp>,
pub end: Option<Timestamp>,
pub reference_gas_price: Option<u64>,
pub protocol_config: Option<ProtocolConfig>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.epoch: Option<u64>committee: Option<ValidatorCommittee>The committee governing this epoch.
bcs_system_state: Option<BcsData>Snapshot of IOTA’s SystemState (0x3::iota_system::SystemState) at the
beginning of the epoch, for past epochs, or the current state for the
current epoch.
first_checkpoint: Option<u64>last_checkpoint: Option<u64>start: Option<Timestamp>end: Option<Timestamp>reference_gas_price: Option<u64>Reference gas price denominated in NANOS
protocol_config: Option<ProtocolConfig>Implementations
Sourceimpl Epoch
impl Epoch
pub const EPOCH_FIELD: &'static MessageField
pub const COMMITTEE_FIELD: &'static MessageField
pub const BCS_SYSTEM_STATE_FIELD: &'static MessageField
pub const FIRST_CHECKPOINT_FIELD: &'static MessageField
pub const LAST_CHECKPOINT_FIELD: &'static MessageField
pub const START_FIELD: &'static MessageField
pub const END_FIELD: &'static MessageField
pub const REFERENCE_GAS_PRICE_FIELD: &'static MessageField
pub const PROTOCOL_CONFIG_FIELD: &'static MessageField
Sourceimpl Epoch
impl Epoch
pub fn path_builder() -> EpochFieldPathBuilder
Sourceimpl Epoch
impl Epoch
Sourcepub fn with_epoch(self, field: u64) -> Self
pub fn with_epoch(self, field: u64) -> Self
Sets epoch with the provided value.
Sourcepub fn with_committee<T: Into<ValidatorCommittee>>(self, field: T) -> Self
pub fn with_committee<T: Into<ValidatorCommittee>>(self, field: T) -> Self
Sets committee with the provided value.
Sourcepub fn with_bcs_system_state<T: Into<BcsData>>(self, field: T) -> Self
pub fn with_bcs_system_state<T: Into<BcsData>>(self, field: T) -> Self
Sets bcs_system_state with the provided value.
Sourcepub fn with_first_checkpoint(self, field: u64) -> Self
pub fn with_first_checkpoint(self, field: u64) -> Self
Sets first_checkpoint with the provided value.
Sourcepub fn with_last_checkpoint(self, field: u64) -> Self
pub fn with_last_checkpoint(self, field: u64) -> Self
Sets last_checkpoint with the provided value.
Sourcepub fn with_start<T: Into<Timestamp>>(self, field: T) -> Self
pub fn with_start<T: Into<Timestamp>>(self, field: T) -> Self
Sets start with the provided value.
Sourcepub fn with_reference_gas_price(self, field: u64) -> Self
pub fn with_reference_gas_price(self, field: u64) -> Self
Sets reference_gas_price with the provided value.
Sourcepub fn with_protocol_config<T: Into<ProtocolConfig>>(self, field: T) -> Self
pub fn with_protocol_config<T: Into<ProtocolConfig>>(self, field: T) -> Self
Sets protocol_config with the provided value.
Sourceimpl Epoch
impl Epoch
Sourcepub fn first_checkpoint(&self) -> u64
pub fn first_checkpoint(&self) -> u64
Returns the value of first_checkpoint, or the default value if first_checkpoint is unset.
Sourcepub fn last_checkpoint(&self) -> u64
pub fn last_checkpoint(&self) -> u64
Returns the value of last_checkpoint, or the default value if last_checkpoint is unset.
Sourcepub fn reference_gas_price(&self) -> u64
pub fn reference_gas_price(&self) -> u64
Returns the value of reference_gas_price, or the default value if reference_gas_price is unset.
Sourceimpl Epoch
impl Epoch
Sourcepub fn epoch_id(&self) -> Result<EpochId, TryFromProtoError>
pub fn epoch_id(&self) -> Result<EpochId, TryFromProtoError>
Get the epoch ID.
Requires epoch in the read_mask.
Sourcepub fn committee(&self) -> Result<ValidatorCommittee, TryFromProtoError>
pub fn committee(&self) -> Result<ValidatorCommittee, TryFromProtoError>
Deserialize the validator committee.
Requires committee in the read_mask.
Sourcepub fn system_state_bcs(&self) -> Result<&[u8], TryFromProtoError>
pub fn system_state_bcs(&self) -> Result<&[u8], TryFromProtoError>
Get the raw BCS-encoded system state bytes.
This is a snapshot of IOTA’s SystemState
(0x3::iota_system::SystemState) at the beginning of the epoch (for
past epochs) or the current state (for the current epoch).
Requires bcs_system_state in the read_mask.
Sourcepub fn first_checkpoint_sequence_number(
&self,
) -> Result<CheckpointSequenceNumber, TryFromProtoError>
pub fn first_checkpoint_sequence_number( &self, ) -> Result<CheckpointSequenceNumber, TryFromProtoError>
Get the first checkpoint sequence number in this epoch.
Requires first_checkpoint in the read_mask.
Sourcepub fn last_checkpoint_sequence_number(
&self,
) -> Result<Option<CheckpointSequenceNumber>, TryFromProtoError>
pub fn last_checkpoint_sequence_number( &self, ) -> Result<Option<CheckpointSequenceNumber>, TryFromProtoError>
Get the last checkpoint sequence number in this epoch.
Returns Ok(None) for the current in-progress epoch (field not yet
set).
Sourcepub fn start_ms(&self) -> Result<CheckpointTimestamp, TryFromProtoError>
pub fn start_ms(&self) -> Result<CheckpointTimestamp, TryFromProtoError>
Get the epoch start time in milliseconds.
Requires start in the read_mask.
Sourcepub fn end_ms(&self) -> Result<Option<CheckpointTimestamp>, TryFromProtoError>
pub fn end_ms(&self) -> Result<Option<CheckpointTimestamp>, TryFromProtoError>
Get the epoch end time in milliseconds.
Returns Ok(None) for the current in-progress epoch (field not yet
set).
Sourcepub fn gas_price(&self) -> Result<u64, TryFromProtoError>
pub fn gas_price(&self) -> Result<u64, TryFromProtoError>
Get the reference gas price in NANOS.
Requires reference_gas_price in the read_mask.
Sourcepub fn protocol_config(&self) -> Result<&ProtocolConfig, TryFromProtoError>
pub fn protocol_config(&self) -> Result<&ProtocolConfig, TryFromProtoError>
Get the protocol configuration for this epoch.
Requires protocol_config in the read_mask.